netapp_ontap.models.dcn_cluster_software_install_status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_cluster_software_install_status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnClusterSoftwareInstallStatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnClusterSoftwareInstallStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `active: bool GET`

    Upgrade status.

    Example: false

  `duration: str GET`

    Upgrade duration in ISO 8601 duration format.

    Example: PT2D2H2M2S

  `message: str GET`

    Upgrade status.

    Example: Upgrading node1

  `scope: str GET`

    Scope of the upgrade.

    Valid choices:

    - cluster
    - node
  `start_time: ImpreciseDateTime GET`

    Upgrade start time.

    Example: 2025-05-20T19:00:00.000+0000